require 'gettext/utils'

GetText.create_mofiles(true, "po", "locale")
